# flake8: noqa
# pylint: skip-file
SONARQUBE_AVAILABLE_METRICS = {
    "metrics": [
        {
            "id": "289",
            "key": "new_technical_debt",
            "type": "WORK_DUR",
            "name": "Added Technical Debt",
            "description": "Added technical debt",
            "domain": "Maintainability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "386",
            "key": "analysis_from_sonarqube_9_4",
            "type": "BOOL",
            "name": "Analysis From SonarQube 9.4",
            "description": "Indicates whether the analysis has been run after the upgrade to SonarQube 9.4. It affects how the issues will be detected for branches that use reference branch as the strategy for detecting new code.",
            "domain": "Issues",
            "direction": 0,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "78",
            "key": "blocker_violations",
            "type": "INT",
            "name": "Blocker Issues",
            "description": "Blocker issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "308",
            "key": "bugs",
            "type": "INT",
            "name": "Bugs",
            "description": "Bugs",
            "domain": "Reliability",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "4",
            "key": "classes",
            "type": "INT",
            "name": "Classes",
            "description": "Classes",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "306",
            "key": "code_smells",
            "type": "INT",
            "name": "Code Smells",
            "description": "Code Smells",
            "domain": "Maintainability",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "347",
            "key": "cognitive_complexity",
            "type": "INT",
            "name": "Cognitive Complexity",
            "description": "Cognitive complexity",
            "domain": "Complexity",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "32",
            "key": "comment_lines",
            "type": "INT",
            "name": "Comment Lines",
            "description": "Number of comment lines",
            "domain": "Size",
            "direction": 1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "239",
            "key": "comment_lines_data",
            "type": "DATA",
            "name": "comment_lines_data",
            "domain": "Size",
            "direction": 0,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "33",
            "key": "comment_lines_density",
            "type": "PERCENT",
            "name": "Comments (%)",
            "description": "Comments balanced by ncloc + comment lines",
            "domain": "Size",
            "direction": 1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "27",
            "key": "class_complexity",
            "type": "FLOAT",
            "name": "Complexity / Class",
            "description": "Complexity average by class",
            "domain": "Complexity",
            "direction": -1,
            "qualitative": True,
            "hidden": True,
            "decimalScale": 1
        },
        {
            "id": "38",
            "key": "file_complexity",
            "type": "FLOAT",
            "name": "Complexity / File",
            "description": "Complexity average by file",
            "domain": "Complexity",
            "direction": -1,
            "qualitative": True,
            "hidden": True,
            "decimalScale": 1
        },
        {
            "id": "28",
            "key": "function_complexity",
            "type": "FLOAT",
            "name": "Complexity / Function",
            "description": "Complexity average by function",
            "domain": "Complexity",
            "direction": -1,
            "qualitative": True,
            "hidden": True,
            "decimalScale": 1
        },
        {
            "id": "272",
            "key": "complexity_in_classes",
            "type": "INT",
            "name": "Complexity in Classes",
            "description": "Cyclomatic complexity in classes",
            "domain": "Complexity",
            "direction": -1,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "273",
            "key": "complexity_in_functions",
            "type": "INT",
            "name": "Complexity in Functions",
            "description": "Cyclomatic complexity in functions",
            "domain": "Complexity",
            "direction": -1,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "97",
            "key": "branch_coverage",
            "type": "PERCENT",
            "name": "Condition Coverage",
            "description": "Condition coverage",
            "domain": "Coverage",
            "direction": 1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "178",
            "key": "new_branch_coverage",
            "type": "PERCENT",
            "name": "Condition Coverage on New Code",
            "description": "Condition coverage of new/changed code",
            "domain": "Coverage",
            "direction": 1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "95",
            "key": "conditions_to_cover",
            "type": "INT",
            "name": "Conditions to Cover",
            "description": "Conditions to cover",
            "domain": "Coverage",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "176",
            "key": "new_conditions_to_cover",
            "type": "INT",
            "name": "Conditions to Cover on New Code",
            "description": "Conditions to cover on new code",
            "domain": "Coverage",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "277",
            "key": "confirmed_issues",
            "type": "INT",
            "name": "Confirmed Issues",
            "description": "Confirmed issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "20",
            "key": "coverage",
            "type": "PERCENT",
            "name": "Coverage",
            "description": "Coverage by tests",
            "domain": "Coverage",
            "direction": 1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "172",
            "key": "new_coverage",
            "type": "PERCENT",
            "name": "Coverage on New Code",
            "description": "Coverage of new/changed code",
            "domain": "Coverage",
            "direction": 1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "79",
            "key": "critical_violations",
            "type": "INT",
            "name": "Critical Issues",
            "description": "Critical issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "26",
            "key": "complexity",
            "type": "INT",
            "name": "Cyclomatic Complexity",
            "description": "Cyclomatic complexity",
            "domain": "Complexity",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "181",
            "key": "last_commit_date",
            "type": "MILLISEC",
            "name": "Date of Last Commit",
            "domain": "SCM",
            "direction": 0,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "280",
            "key": "development_cost",
            "type": "STRING",
            "name": "Development Cost",
            "description": "Development cost",
            "domain": "Maintainability",
            "direction": -1,
            "qualitative": True,
            "hidden": True
        },
        {
            "id": "348",
            "key": "new_development_cost",
            "type": "FLOAT",
            "name": "Development Cost on New Code",
            "description": "Development cost on new code",
            "domain": "Maintainability",
            "direction": -1,
            "qualitative": True,
            "hidden": True,
            "decimalScale": 1
        },
        {
            "id": "37",
            "key": "directories",
            "type": "INT",
            "name": "Directories",
            "description": "Directories",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "51",
            "key": "duplicated_blocks",
            "type": "INT",
            "name": "Duplicated Blocks",
            "description": "Duplicated blocks",
            "domain": "Duplications",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "339",
            "key": "new_duplicated_blocks",
            "type": "INT",
            "name": "Duplicated Blocks on New Code",
            "description": "Duplicated blocks on new code",
            "domain": "Duplications",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "52",
            "key": "duplicated_files",
            "type": "INT",
            "name": "Duplicated Files",
            "description": "Duplicated files",
            "domain": "Duplications",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "8",
            "key": "duplicated_lines",
            "type": "INT",
            "name": "Duplicated Lines",
            "description": "Duplicated lines",
            "domain": "Duplications",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "34",
            "key": "duplicated_lines_density",
            "type": "PERCENT",
            "name": "Duplicated Lines (%)",
            "description": "Duplicated lines balanced by statements",
            "domain": "Duplications",
            "direction": -1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "340",
            "key": "new_duplicated_lines_density",
            "type": "PERCENT",
            "name": "Duplicated Lines (%) on New Code",
            "description": "Duplicated lines (%) on new code balanced by statements",
            "domain": "Duplications",
            "direction": -1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "338",
            "key": "new_duplicated_lines",
            "type": "INT",
            "name": "Duplicated Lines on New Code",
            "description": "Duplicated Lines on New Code",
            "domain": "Duplications",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "53",
            "key": "duplications_data",
            "type": "DATA",
            "name": "Duplication Details",
            "description": "Duplications details",
            "domain": "Duplications",
            "direction": 0,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "312",
            "key": "effort_to_reach_maintainability_rating_a",
            "type": "WORK_DUR",
            "name": "Effort to Reach Maintainability Rating A",
            "description": "Effort to reach maintainability rating A",
            "domain": "Maintainability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "321",
            "key": "executable_lines_data",
            "type": "DATA",
            "name": "executable_lines_data",
            "domain": "Coverage",
            "direction": 0,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "274",
            "key": "False_positive_issues",
            "type": "INT",
            "name": "False Positive Issues",
            "description": "False positive issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "154",
            "key": "file_complexity_distribution",
            "type": "DISTRIB",
            "name": "File Distribution / Complexity",
            "description": "Files distribution /complexity",
            "domain": "Complexity",
            "direction": 0,
            "qualitative": True,
            "hidden": True
        },
        {
            "id": "36",
            "key": "files",
            "type": "INT",
            "name": "Files",
            "description": "Number of files",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "59",
            "key": "function_complexity_distribution",
            "type": "DISTRIB",
            "name": "Function Distribution / Complexity",
            "description": "Functions distribution /complexity",
            "domain": "Complexity",
            "direction": 0,
            "qualitative": True,
            "hidden": True
        },
        {
            "id": "6",
            "key": "functions",
            "type": "INT",
            "name": "Functions",
            "description": "Functions",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "150",
            "key": "generated_lines",
            "type": "INT",
            "name": "Generated Lines",
            "description": "Number of generated lines",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "151",
            "key": "generated_ncloc",
            "type": "INT",
            "name": "Generated Lines of Code",
            "description": "Generated non Commenting Lines of Code",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "82",
            "key": "info_violations",
            "type": "INT",
            "name": "Info Issues",
            "description": "Info issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "42",
            "key": "violations",
            "type": "INT",
            "name": "Issues",
            "description": "Issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "94",
            "key": "line_coverage",
            "type": "PERCENT",
            "name": "Line Coverage",
            "description": "Line coverage",
            "domain": "Coverage",
            "direction": 1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "175",
            "key": "new_line_coverage",
            "type": "PERCENT",
            "name": "Line Coverage on New Code",
            "description": "Line coverage of added/changed code",
            "domain": "Coverage",
            "direction": 1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "55",
            "key": "lines",
            "type": "INT",
            "name": "Lines",
            "description": "Lines",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "5",
            "key": "ncloc",
            "type": "INT",
            "name": "Lines of Code",
            "description": "Non commenting lines of code",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "293",
            "key": "ncloc_language_distribution",
            "type": "DATA",
            "name": "Lines of Code Per Language",
            "description": "Non Commenting Lines of Code Distributed By Language",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "92",
            "key": "lines_to_cover",
            "type": "INT",
            "name": "Lines to Cover",
            "description": "Lines to cover",
            "domain": "Coverage",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "173",
            "key": "new_lines_to_cover",
            "type": "INT",
            "name": "Lines to Cover on New Code",
            "description": "Lines to cover on new code",
            "domain": "Coverage",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "163",
            "key": "sqale_rating",
            "type": "RATING",
            "name": "Maintainability Rating",
            "description": "A-to-E rating based on the technical debt ratio",
            "domain": "Maintainability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "341",
            "key": "new_maintainability_rating",
            "type": "RATING",
            "name": "Maintainability Rating on New Code",
            "description": "Maintainability rating on new code",
            "domain": "Maintainability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "80",
            "key": "major_violations",
            "type": "INT",
            "name": "Major Issues",
            "description": "Major issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "81",
            "key": "minor_violations",
            "type": "INT",
            "name": "Minor Issues",
            "description": "Minor issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "238",
            "key": "ncloc_data",
            "type": "DATA",
            "name": "ncloc_data",
            "domain": "Size",
            "direction": 0,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "165",
            "key": "new_blocker_violations",
            "type": "INT",
            "name": "New Blocker Issues",
            "description": "New Blocker issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "309",
            "key": "new_bugs",
            "type": "INT",
            "name": "New Bugs",
            "description": "New Bugs",
            "domain": "Reliability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "307",
            "key": "new_code_smells",
            "type": "INT",
            "name": "New Code Smells",
            "description": "New Code Smells",
            "domain": "Maintainability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "166",
            "key": "new_critical_violations",
            "type": "INT",
            "name": "New Critical Issues",
            "description": "New Critical issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "169",
            "key": "new_info_violations",
            "type": "INT",
            "name": "New Info Issues",
            "description": "New Info issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "164",
            "key": "new_violations",
            "type": "INT",
            "name": "New Issues",
            "description": "New issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "337",
            "key": "new_lines",
            "type": "INT",
            "name": "New Lines",
            "description": "New lines",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "167",
            "key": "new_major_violations",
            "type": "INT",
            "name": "New Major Issues",
            "description": "New Major issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "168",
            "key": "new_minor_violations",
            "type": "INT",
            "name": "New Minor Issues",
            "description": "New Minor issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "351",
            "key": "new_security_hotspots",
            "type": "INT",
            "name": "New Security Hotspots",
            "description": "New Security Hotspots",
            "domain": "SecurityReview",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "311",
            "key": "new_vulnerabilities",
            "type": "INT",
            "name": "New Vulnerabilities",
            "description": "New Vulnerabilities",
            "domain": "Security",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "275",
            "key": "open_issues",
            "type": "INT",
            "name": "Open Issues",
            "description": "Open issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "47",
            "key": "quality_profiles",
            "type": "DATA",
            "name": "Profiles",
            "description": "Details of quality profiles used during analysis",
            "domain": "General",
            "direction": 0,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "240",
            "key": "projects",
            "type": "INT",
            "name": "Project branches",
            "description": "Number of project branches",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "58",
            "key": "public_api",
            "type": "INT",
            "name": "Public API",
            "description": "Public API",
            "domain": "Documentation",
            "direction": -1,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "61",
            "key": "public_documented_api_density",
            "type": "PERCENT",
            "name": "Public Documented API (%)",
            "description": "Public documented classes and functions balanced by ncloc",
            "domain": "Documentation",
            "direction": 1,
            "qualitative": True,
            "hidden": True,
            "decimalScale": 1
        },
        {
            "id": "62",
            "key": "public_undocumented_api",
            "type": "INT",
            "name": "Public Undocumented API",
            "description": "Public undocumented classes, functions and variables",
            "domain": "Documentation",
            "direction": -1,
            "qualitative": True,
            "hidden": True
        },
        {
            "id": "294",
            "key": "quality_gate_details",
            "type": "DATA",
            "name": "Quality Gate Details",
            "description": "The project detailed status with regard to its quality gate",
            "domain": "General",
            "direction": 0,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "48",
            "key": "alert_status",
            "type": "LEVEL",
            "name": "Quality Gate Status",
            "description": "The project status with regard to its quality gate.",
            "domain": "Releasability",
            "direction": 1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "315",
            "key": "reliability_rating",
            "type": "RATING",
            "name": "Reliability Rating",
            "description": "Reliability rating",
            "domain": "Reliability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "342",
            "key": "new_reliability_rating",
            "type": "RATING",
            "name": "Reliability Rating on New Code",
            "description": "Reliability rating on new code",
            "domain": "Reliability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "313",
            "key": "reliability_remediation_effort",
            "type": "WORK_DUR",
            "name": "Reliability Remediation Effort",
            "description": "Reliability Remediation Effort",
            "domain": "Reliability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "314",
            "key": "new_reliability_remediation_effort",
            "type": "WORK_DUR",
            "name": "Reliability Remediation Effort on New Code",
            "description": "Reliability remediation effort on new code",
            "domain": "Reliability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "276",
            "key": "reopened_issues",
            "type": "INT",
            "name": "Reopened Issues",
            "description": "Reopened issues",
            "domain": "Issues",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "350",
            "key": "security_hotspots",
            "type": "INT",
            "name": "Security Hotspots",
            "description": "Security Hotspots",
            "domain": "SecurityReview",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "354",
            "key": "security_hotspots_reviewed",
            "type": "PERCENT",
            "name": "Security Hotspots Reviewed",
            "description": "Percentage of Security Hotspots Reviewed",
            "domain": "SecurityReview",
            "direction": 1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "355",
            "key": "new_security_hotspots_reviewed",
            "type": "PERCENT",
            "name": "Security Hotspots Reviewed on New Code",
            "description": "Percentage of Security Hotspots Reviewed on New Code",
            "domain": "SecurityReview",
            "direction": 1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        },
        {
            "id": "319",
            "key": "security_rating",
            "type": "RATING",
            "name": "Security Rating",
            "description": "Security rating",
            "domain": "Security",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "343",
            "key": "new_security_rating",
            "type": "RATING",
            "name": "Security Rating on New Code",
            "description": "Security rating on new code",
            "domain": "Security",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "317",
            "key": "security_remediation_effort",
            "type": "WORK_DUR",
            "name": "Security Remediation Effort",
            "description": "Security remediation effort",
            "domain": "Security",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "318",
            "key": "new_security_remediation_effort",
            "type": "WORK_DUR",
            "name": "Security Remediation Effort on New Code",
            "description": "Security remediation effort on new code",
            "domain": "Security",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "352",
            "key": "security_review_rating",
            "type": "RATING",
            "name": "Security Review Rating",
            "description": "Security Review Rating",
            "domain": "SecurityReview",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "353",
            "key": "new_security_review_rating",
            "type": "RATING",
            "name": "Security Review Rating on New Code",
            "description": "Security Review Rating on New Code",
            "domain": "SecurityReview",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "356",
            "key": "security_hotspots_reviewed_status",
            "type": "INT",
            "name": "Security Review Reviewed Status",
            "description": "Security Review Reviewed Status",
            "domain": "SecurityReview",
            "direction": -1,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "358",
            "key": "new_security_hotspots_reviewed_status",
            "type": "INT",
            "name": "Security Review Reviewed Status on New Code",
            "description": "Security Review Reviewed Status on New Code",
            "domain": "SecurityReview",
            "direction": -1,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "357",
            "key": "security_hotspots_to_review_status",
            "type": "INT",
            "name": "Security Review To Review Status",
            "description": "Security Review To Review Status",
            "domain": "SecurityReview",
            "direction": -1,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "359",
            "key": "new_security_hotspots_to_review_status",
            "type": "INT",
            "name": "Security Review To Review Status on New Code",
            "description": "Security Review To Review Status on New Code",
            "domain": "SecurityReview",
            "direction": -1,
            "qualitative": False,
            "hidden": True
        },
        {
            "id": "11",
            "key": "skipped_tests",
            "type": "INT",
            "name": "Skipped Unit Tests",
            "description": "Number of skipped unit tests",
            "domain": "Coverage",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "60",
            "key": "statements",
            "type": "INT",
            "name": "Statements",
            "description": "Number of statements",
            "domain": "Size",
            "direction": -1,
            "qualitative": False,
            "hidden": False
        },
        {
            "id": "162",
            "key": "sqale_index",
            "type": "WORK_DUR",
            "name": "Technical Debt",
            "description": "Total effort (in hours) to fix all the issues on the component and therefore to comply to all the requirements.",
            "domain": "Maintainability",
            "direction": -1,
            "qualitative": True,
            "hidden": False
        },
        {
            "id": "297",
            "key": "sqale_debt_ratio",
            "type": "PERCENT",
            "name": "Technical Debt Ratio",
            "description": "Ratio of the actual technical debt compared to the estimated cost to develop the whole source code from scratch",
            "domain": "Maintainability",
            "direction": -1,
            "qualitative": True,
            "hidden": False,
            "decimalScale": 1
        }
    ],
    "total": 112,
    "p": 1,
    "ps": 100
}
